#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get alltube.@alltube[0].image_name 2>/dev/null)
}

do_install_detail() {
  local config=$(uci get alltube.@alltube[0].config_path 2>/dev/null)
  local port=$(uci get alltube.@alltube[0].port 2>/dev/null)
  local IMAGE_NAME=$(uci get alltube.@alltube[0].image_name 2>/dev/null)
  local username=$(uci get alltube.@alltube[0].username 2>/dev/null)
  local password=$(uci get alltube.@alltube[0].password 2>/dev/null)

  # Generate random passwords similar to Searxng script
  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"

  [ -z "$config" ] && echo "config path is empty!" && exit 1
  [ -z "$port" ] && port=5993
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=rudloff/alltube

  # Create Docker Compose file with custom variables
  rm -R /opt/docker2/compose/alltube-app
  mkdir /opt/docker2/compose/alltube-app
  touch /opt/docker2/compose/alltube-app/docker-compose.yml
  cat > /opt/docker2/compose/alltube-app/docker-compose.yml <<EOF
version: '3.3'
services:
    alltube:
        image: $IMAGE_NAME
        ports:
            - ${LAN_IP}:$port:80
        environment:
            - PUID=1026
            - PGID=100
            - TZ=Europe/Bucharest
        restart: always
EOF
  
  docker-compose -f /opt/docker2/compose/alltube-app/docker-compose.yml up -d

  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install alltube"
  echo "      upgrade                Upgrade alltube"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart alltube"
  echo "      status                 alltube status"
  echo "      port                   alltube port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    for ID in $CONTAINER_IDS; do
      docker stop $ID
      docker rm $ID
    done
    docker rmi -f $IMAGE_NAME
  ;;
  "start"|"stop"|"restart")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    for ID in $CONTAINER_IDS; do
      docker ${ACTION} ${ID}
    done
  ;;
  "status")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac